import { Component, OnInit, Input } from '@angular/core';
import { MatStepper, MatDialog } from '@angular/material';
import { CaDeploymentChannelsModalComponent } from '../ca-deployment-channels-modal/ca-deployment-channels-modal.component';
import { AgentService } from '../../../service/agent.service';
import { first } from 'rxjs/operators';
import { NotificationType, NotificationService } from '@xdf/commons';
import { TranslateService } from '@ngx-translate/core';
import { Router } from '@angular/router';

@Component({
  selector: 'byte-ca-deployment-channels',
  templateUrl: './ca-deployment-channels.component.html',
  styleUrls: ['./ca-deployment-channels.component.scss']
})
export class CaDeploymentChannelsComponent implements OnInit {

  @Input() stepper: MatStepper;

  agentDetail: any;
  channels: Array<any>;
  deploymentChannels: Array<any> = new Array<any>();
  dirty: boolean = true;
  step = -1;

  constructor(
    private agentService: AgentService,
    private matDialog: MatDialog,
    private translateService: TranslateService,
    private notificationService: NotificationService,
    private router: Router
  ) { }

  ngOnInit() {

    this.agentService.getChannelDatForWizard().pipe(first()).subscribe((result: any) => {
      if (result) {
        this.channels = result;
      } else {
        this.channels = [];
      }

      this.buildList();
    });
  }

  buildForm(agentDetail: any) {
    this.agentDetail = agentDetail;
    this.deploymentChannels = agentDetail.deploymentChannels;
    this.buildList();
  }

  buildList() {
    if (this.channels && this.deploymentChannels) {
      for (let deploymentChannel of this.deploymentChannels) {
        for (let channel of this.channels) {
          if (channel.id === deploymentChannel.channelId) {

            deploymentChannel.channelName = channel.name;
            deploymentChannel.channelImage = channel.image;


            for (let parameter of deploymentChannel.parameters) {
              for (let field of channel.parameters) {

                if (parameter.channelParamName === field.name) {
                  parameter.label = field.label;
                  parameter.type = field.type;
                  parameter.required = field.required;
                  parameter.traductions = field.traductions;
                  parameter.maxlength = field.maxlength;
                  break;
                }

              }
            }

            break;
          }
        }
      }
    }
  }

  addChannel() {
    let dialog = this.matDialog.open(CaDeploymentChannelsModalComponent, {
      width: '500px',
      data: {
        message: '',
        channels: this.channels
      }
    });

    dialog.afterClosed().subscribe(result => {
      if (result) {
        let selectedChannel = { ...result };

        selectedChannel.channelId = selectedChannel.id;
        selectedChannel.channelName = selectedChannel.name;
        selectedChannel.channelImage = selectedChannel.image;
        selectedChannel.id = undefined;
        selectedChannel.name = undefined;

        this.deploymentChannels.push(selectedChannel);
        this.setStep(this.deploymentChannels.length - 1);
      }
    });
  }

  deleteChannel(i) {
    this.deploymentChannels.splice(i, 1);
  }

  setStep(step) {
    this.step = step;
  }


  save() {

    let agent: any = {};

    agent.id = this.agentDetail.id;
    agent.name = this.agentDetail.name;
    agent.description = this.agentDetail.description;
    agent.version = this.agentDetail.version;
    agent.countryId = this.agentDetail.countryId;
    agent.timezone = this.agentDetail.timezone;
    agent.avatar = this.agentDetail.avatar;
    agent.language = this.agentDetail.language;
    agent.type = this.agentDetail.type;
    agent.status = this.agentDetail.status;
    agent.deploymentChannels = [];

    for (let deploymentChannel of this.deploymentChannels) {
      let deploymentChannelTmp: any = {};

      deploymentChannelTmp.id = deploymentChannel.id;
      deploymentChannelTmp.name = deploymentChannel.name;
      deploymentChannelTmp.status = deploymentChannel.status ? deploymentChannel.status : 'AC';
      deploymentChannelTmp.channelId = deploymentChannel.channelId;
      deploymentChannelTmp.parameters = [];

      for (let parameter of deploymentChannel.parameters) {
        let parameterTmp: any = {};

        parameterTmp.id = parameter.id;
        parameterTmp.value = parameter.value;
        parameterTmp.channelParamName = parameter.channelParamName ? parameter.channelParamName : parameter.name;

        deploymentChannelTmp.parameters.push(parameterTmp);
      }

      agent.deploymentChannels.push(deploymentChannelTmp);
    }

    agent.frequentQuestions = this.agentDetail.frequentQuestions;

    console.log(agent);

    this.agentService.update(agent.id, agent).pipe(first()).subscribe(() => {

      if (agent.id) {
        this.dirty = false;
        this.notificationService.showMessage(this.translateService.instant('agent.edit.success'), null, NotificationType.success);
        this.router.navigate(['/configuration/agent']);
      } else {
        this.dirty = false;
        this.notificationService.showMessage(this.translateService.instant('agent.create.success'), null, NotificationType.success);
        this.router.navigate(['/configuration/agent']);
      }
    });

  }

}
