import { Component, OnInit, Input, ViewContainerRef, ElementRef, ViewChild, ChangeDetectorRef } from '@angular/core';
import { Subscription, of } from 'rxjs';
import { FormGroup, FormBuilder, FormControl } from '@angular/forms';
import { MatStepper, MatDialog, MatTableDataSource, MatSort } from '@angular/material';
import { ActivatedRoute, Router } from '@angular/router';
import { animate, trigger, state, transition, style } from '@angular/animations';
import { DomSanitizer } from '@angular/platform-browser';
import { AuthorizationService } from '@xdf/security';
import { TranslateService } from '@ngx-translate/core';
import { catchError, map } from 'rxjs/operators';
import { HttpEventType, HttpErrorResponse } from '@angular/common/http';
import { UploadService } from '../upload.service';
import { CaFileUploadModalComponent, FileUploadModel } from '../ca-file-upload-modal/ca-file-upload-modal.component';

@Component({
  selector: 'byte-ca-frequent-questions',
  templateUrl: './ca-frequent-questions.component.html',
  styleUrls: ['./ca-frequent-questions.component.scss'],
  animations: [
    trigger('fadeInOut', [
      state('in', style({ opacity: 100 })),
      transition('* => void', [
        animate(300, style({ opacity: 0 }))
      ])
    ])
  ]
})
export class CaFrequentQuestionsComponent implements OnInit {

  @Input() stepper: MatStepper;

  viewMode: boolean;

  public resourceAuth = new Object();

  accept = '.xls,.xlsx';

  displayedColumns: string[] = ['id', 'filename', 'description', 'status', 'user', 'uploadDate', 'actions'];
  dataSource = new MatTableDataSource<FileUploadModel>();
  @ViewChild(MatSort, { static: false }) sort: MatSort;

  mapStatus = {
    "LO": {
      "text": "label.status.loaded",
      "class": "label label-primary"
    },
    "PS": {
      "text": "label.status.pending",
      "class": "label label-warning"
    }
  };

  files = [];

  constructor(protected route: ActivatedRoute,
    protected router: Router,
    protected vcRef: ViewContainerRef,
    protected authorizationService: AuthorizationService,
    private translate: TranslateService,
    private uploadService: UploadService,
    private _activatedRoute: ActivatedRoute,
    private matDialog: MatDialog,
    private changeDetectorRefs: ChangeDetectorRef
  ) {

    this.viewMode = this._activatedRoute.snapshot.data.mode === 'view';

  }

  ngOnInit() {
    const keyAuthorization = 'authorization';
    const authList = this.route.snapshot.paramMap[keyAuthorization];
    if (authList) {
      this.resourceAuth = new Object();
      authList.forEach(option => {
        this.resourceAuth[option] = true;
      });
    }

  }

  isDirty() {
    return false;
  }

  buildForm(agentDetail: any) {
    this.dataSource.data = agentDetail.frequentQuestions;
  }

  setDataForWizard(result: any) {
    console.log(result)
    /*
    this.protocols = result.connectionProtocolOptions;
    this.generalProperties = result.generalProperties;
    this.alias = result.alias;
    this.maxNumberOfConnectionsByExternalSystem = result.maxNumberOfConnectionsByExternalSystem;
    this.columnsForEntity = result.columnsForEntity;
    */
  }

  ngAfterViewInit() {
    this.dataSource.sort = this.sort;
  }

  getClassStatus(status) {
    return this.mapStatus[status].class;
  }

  getTextStatus(status) {
    return this.translate.instant(this.mapStatus[status].text);
  }

  addFile() {
    let dialog = this.matDialog.open(CaFileUploadModalComponent, {
      width: '500px'
    });

    dialog.afterClosed().subscribe(result => {
      if (result) {
        let fileAdded = { ...result };
        let listTemp = this.dataSource.data;
        listTemp.push(fileAdded);
        this.dataSource.data = listTemp;
      }
    });
  }

  saveQuestions(validateForm: boolean) {
    let success = true;

    return success;
  }

  onDeleteRecord(item, index) {
    let listTemp = this.dataSource.data;
    listTemp.splice(index, 1);
    this.dataSource.data = listTemp;
  }

  next() {
    if (!this.dataSource.data.length) {
      return;
    }

    if (this.viewMode) {
      this.stepper.next();
      return;
    }

    if (this.saveQuestions(true)) {
      this.stepper.next();
    }
  }

}
